@@ -1,7 +1,7 @@
 #
 # Session - Itcl object for web session management for Rivet
 #
-# $Id: session-class.tcl 1337565 2012-05-12 15:21:33Z mxmanghi $
+# $Id: session-class.tcl 1373643 2012-08-15 21:45:39Z mxmanghi $
 #
 
 # Copyright 2004 The Apache Software Foundation
@@ -105,8 +105,8 @@ package require Itcl
 
     constructor {args} {
 	eval configure $args
-    	$dioObject registerSpecialField rivet_session session_update_time NOW
-	$dioObject registerSpecialField rivet_session session_start_time NOW
+    	$dioObject registerSpecialField $sessionTable session_update_time NOW
+	$dioObject registerSpecialField $sessionTable session_start_time NOW
     }
 
     method status {args} {
@@ -353,7 +353,6 @@ package require Itcl
     # sessions)
     #
     method delete_session {{session_id ""}} {
-	variable conf
 
 	set ip_address [env REMOTE_ADDR]
 
@@ -377,7 +376,6 @@ package require Itcl
     # returns the session_id
     #
     method create_session {} {
-	global conf
 
 	## Create their session by storing their session information in 
 	# the session table.
