@@ -12,10 +12,12 @@
 ##              list attribute-value pairs to be given
 ##              to the <table> element tag
 ##
-## $Id: parray_table.tcl 1340770 2012-05-20 17:11:00Z mxmanghi $
+## $Id: parray_table.tcl 1231782 2012-01-15 22:40:35Z mxmanghi $
 ##
 ##
 
+namespace eval ::rivet {
+
     proc parray_table {arrayName {pattern "*"} {htmlAttributes ""}} {
         upvar 1 $arrayName array
         if {![array exists array]} {
@@ -33,3 +35,5 @@
         }
         puts stdout "</tbody></table>"
     }
+
+}
